==> haskell-zlib-bindings-0.1.1.5-176-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib-bindings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-5aeoSQiM6rOLrjoidewaip
key:                  zlib-bindings-0.1.1.5-5aeoSQiM6rOLrjoidewaip
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  91d43f526a3f0637931a62252172a642
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.4.8/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/zlib-bindings-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-5aeoSQiM6rOLrjoidewaip
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    zlib-0.6.3.0-Lc3DHeTx2uhI5X6rGvkbLK

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-bindings-0.1.1.5-177-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib-bindings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-4cJrN1232X79FNZJraqAhs
key:                  zlib-bindings-0.1.1.5-4cJrN1232X79FNZJraqAhs
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  acfa5e31825064032951f65694020cc1
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.4.8/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/zlib-bindings-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-4cJrN1232X79FNZJraqAhs
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    zlib-0.6.3.0-pMzhPqoz0vBGpJZmwR4eF

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
